Class: Aws::CloudDirectory::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CloudDirectory::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-clouddirectory/client.rb,
sig/client.rbs
Overview
An API client for CloudDirectory. To construct a client, you need to configure a :region and :credentials.
client = Aws::CloudDirectory::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AddFacetToObjectResponseSuccess, _ApplySchemaResponseSuccess, _AttachObjectResponseSuccess, _AttachPolicyResponseSuccess, _AttachToIndexResponseSuccess, _AttachTypedLinkResponseSuccess, _BatchReadResponseSuccess, _BatchWriteResponseSuccess, _CreateDirectoryResponseSuccess, _CreateFacetResponseSuccess, _CreateIndexResponseSuccess, _CreateObjectResponseSuccess, _CreateSchemaResponseSuccess, _CreateTypedLinkFacetResponseSuccess, _DeleteDirectoryResponseSuccess, _DeleteFacetResponseSuccess, _DeleteObjectResponseSuccess, _DeleteSchemaResponseSuccess, _DeleteTypedLinkFacetResponseSuccess, _DetachFromIndexResponseSuccess, _DetachObjectResponseSuccess, _DetachPolicyResponseSuccess, _DisableDirectoryResponseSuccess, _EnableDirectoryResponseSuccess, _GetAppliedSchemaVersionResponseSuccess, _GetDirectoryResponseSuccess, _GetFacetResponseSuccess, _GetLinkAttributesResponseSuccess, _GetObjectAttributesResponseSuccess, _GetObjectInformationResponseSuccess, _GetSchemaAsJsonResponseSuccess, _GetTypedLinkFacetInformationResponseSuccess, _ListAppliedSchemaArnsResponseSuccess, _ListAttachedIndicesResponseSuccess, _ListDevelopmentSchemaArnsResponseSuccess, _ListDirectoriesResponseSuccess, _ListFacetAttributesResponseSuccess, _ListFacetNamesResponseSuccess, _ListIncomingTypedLinksResponseSuccess, _ListIndexResponseSuccess, _ListManagedSchemaArnsResponseSuccess, _ListObjectAttributesResponseSuccess, _ListObjectChildrenResponseSuccess, _ListObjectParentPathsResponseSuccess, _ListObjectParentsResponseSuccess, _ListObjectPoliciesResponseSuccess, _ListOutgoingTypedLinksResponseSuccess, _ListPolicyAttachmentsResponseSuccess, _ListPublishedSchemaArnsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTypedLinkFacetAttributesResponseSuccess, _ListTypedLinkFacetNamesResponseSuccess, _LookupPolicyResponseSuccess, _PublishSchemaResponseSuccess, _PutSchemaFromJsonResponseSuccess, _RemoveFacetFromObjectResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateFacetResponseSuccess, _UpdateLinkAttributesResponseSuccess, _UpdateObjectAttributesResponseSuccess, _UpdateSchemaResponseSuccess, _UpdateTypedLinkFacetResponseSuccess, _UpgradeAppliedSchemaResponseSuccess, _UpgradePublishedSchemaResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_facet_to_object(params = {}) ⇒ Struct
Adds a new Facet to an object.
-
#apply_schema(params = {}) ⇒ Types::ApplySchemaResponse
Copies the input published schema, at the specified version, into the Directory with the same name and version as that of the published schema.
-
#attach_object(params = {}) ⇒ Types::AttachObjectResponse
Attaches an existing object to another object.
-
#attach_policy(params = {}) ⇒ Struct
Attaches a policy object to a regular object.
-
#attach_to_index(params = {}) ⇒ Types::AttachToIndexResponse
Attaches the specified object to the specified index.
-
#attach_typed_link(params = {}) ⇒ Types::AttachTypedLinkResponse
Attaches a typed link to a specified source and target object.
-
#batch_read(params = {}) ⇒ Types::BatchReadResponse
Performs all the read operations in a batch.
-
#batch_write(params = {}) ⇒ Types::BatchWriteResponse
Performs all the write operations in a batch.
-
#create_directory(params = {}) ⇒ Types::CreateDirectoryResponse
Creates a Directory by copying the published schema into the directory.
-
#create_facet(params = {}) ⇒ Struct
Creates a new Facet in a schema.
-
#create_index(params = {}) ⇒ Types::CreateIndexResponse
Creates an index object.
-
#create_object(params = {}) ⇒ Types::CreateObjectResponse
Creates an object in a Directory.
-
#create_schema(params = {}) ⇒ Types::CreateSchemaResponse
Creates a new schema in a development state.
-
#create_typed_link_facet(params = {}) ⇒ Struct
Creates a TypedLinkFacet.
-
#delete_directory(params = {}) ⇒ Types::DeleteDirectoryResponse
Deletes a directory.
-
#delete_facet(params = {}) ⇒ Struct
Deletes a given Facet.
-
#delete_object(params = {}) ⇒ Struct
Deletes an object and its associated attributes.
-
#delete_schema(params = {}) ⇒ Types::DeleteSchemaResponse
Deletes a given schema.
-
#delete_typed_link_facet(params = {}) ⇒ Struct
Deletes a TypedLinkFacet.
-
#detach_from_index(params = {}) ⇒ Types::DetachFromIndexResponse
Detaches the specified object from the specified index.
-
#detach_object(params = {}) ⇒ Types::DetachObjectResponse
Detaches a given object from the parent object.
-
#detach_policy(params = {}) ⇒ Struct
Detaches a policy from an object.
-
#detach_typed_link(params = {}) ⇒ Struct
Detaches a typed link from a specified source and target object.
-
#disable_directory(params = {}) ⇒ Types::DisableDirectoryResponse
Disables the specified directory.
-
#enable_directory(params = {}) ⇒ Types::EnableDirectoryResponse
Enables the specified directory.
-
#get_applied_schema_version(params = {}) ⇒ Types::GetAppliedSchemaVersionResponse
Returns current applied schema version ARN, including the minor version in use.
-
#get_directory(params = {}) ⇒ Types::GetDirectoryResponse
Retrieves metadata about a directory.
-
#get_facet(params = {}) ⇒ Types::GetFacetResponse
Gets details of the Facet, such as facet name, attributes, Rules, or
ObjectType. -
#get_link_attributes(params = {}) ⇒ Types::GetLinkAttributesResponse
Retrieves attributes that are associated with a typed link.
-
#get_object_attributes(params = {}) ⇒ Types::GetObjectAttributesResponse
Retrieves attributes within a facet that are associated with an object.
-
#get_object_information(params = {}) ⇒ Types::GetObjectInformationResponse
Retrieves metadata about an object.
-
#get_schema_as_json(params = {}) ⇒ Types::GetSchemaAsJsonResponse
Retrieves a JSON representation of the schema.
-
#get_typed_link_facet_information(params = {}) ⇒ Types::GetTypedLinkFacetInformationResponse
Returns the identity attribute order for a specific TypedLinkFacet.
-
#list_applied_schema_arns(params = {}) ⇒ Types::ListAppliedSchemaArnsResponse
Lists schema major versions applied to a directory.
-
#list_attached_indices(params = {}) ⇒ Types::ListAttachedIndicesResponse
Lists indices attached to the specified object.
-
#list_development_schema_arns(params = {}) ⇒ Types::ListDevelopmentSchemaArnsResponse
Retrieves each Amazon Resource Name (ARN) of schemas in the development state.
-
#list_directories(params = {}) ⇒ Types::ListDirectoriesResponse
Lists directories created within an account.
-
#list_facet_attributes(params = {}) ⇒ Types::ListFacetAttributesResponse
Retrieves attributes attached to the facet.
-
#list_facet_names(params = {}) ⇒ Types::ListFacetNamesResponse
Retrieves the names of facets that exist in a schema.
-
#list_incoming_typed_links(params = {}) ⇒ Types::ListIncomingTypedLinksResponse
Returns a paginated list of all the incoming TypedLinkSpecifier information for an object.
-
#list_index(params = {}) ⇒ Types::ListIndexResponse
Lists objects attached to the specified index.
-
#list_managed_schema_arns(params = {}) ⇒ Types::ListManagedSchemaArnsResponse
Lists the major version families of each managed schema.
-
#list_object_attributes(params = {}) ⇒ Types::ListObjectAttributesResponse
Lists all attributes that are associated with an object.
-
#list_object_children(params = {}) ⇒ Types::ListObjectChildrenResponse
Returns a paginated list of child objects that are associated with a given object.
-
#list_object_parent_paths(params = {}) ⇒ Types::ListObjectParentPathsResponse
Retrieves all available parent paths for any object type such as node, leaf node, policy node, and index node objects.
-
#list_object_parents(params = {}) ⇒ Types::ListObjectParentsResponse
Lists parent objects that are associated with a given object in pagination fashion.
-
#list_object_policies(params = {}) ⇒ Types::ListObjectPoliciesResponse
Returns policies attached to an object in pagination fashion.
-
#list_outgoing_typed_links(params = {}) ⇒ Types::ListOutgoingTypedLinksResponse
Returns a paginated list of all the outgoing TypedLinkSpecifier information for an object.
-
#list_policy_attachments(params = {}) ⇒ Types::ListPolicyAttachmentsResponse
Returns all of the
ObjectIdentifiersto which a given policy is attached. -
#list_published_schema_arns(params = {}) ⇒ Types::ListPublishedSchemaArnsResponse
Lists the major version families of each published schema.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns tags for a resource.
-
#list_typed_link_facet_attributes(params = {}) ⇒ Types::ListTypedLinkFacetAttributesResponse
Returns a paginated list of all attribute definitions for a particular TypedLinkFacet.
-
#list_typed_link_facet_names(params = {}) ⇒ Types::ListTypedLinkFacetNamesResponse
Returns a paginated list of
TypedLinkfacet names for a particular schema. -
#lookup_policy(params = {}) ⇒ Types::LookupPolicyResponse
Lists all policies from the root of the Directory to the object specified.
-
#publish_schema(params = {}) ⇒ Types::PublishSchemaResponse
Publishes a development schema with a major version and a recommended minor version.
-
#put_schema_from_json(params = {}) ⇒ Types::PutSchemaFromJsonResponse
Allows a schema to be updated using JSON upload.
-
#remove_facet_from_object(params = {}) ⇒ Struct
Removes the specified facet from the specified object.
-
#tag_resource(params = {}) ⇒ Struct
An API operation for adding tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
An API operation for removing tags from a resource.
-
#update_facet(params = {}) ⇒ Struct
Does the following:.
-
#update_link_attributes(params = {}) ⇒ Struct
Updates a given typed link’s attributes.
-
#update_object_attributes(params = {}) ⇒ Types::UpdateObjectAttributesResponse
Updates a given object's attributes.
-
#update_schema(params = {}) ⇒ Types::UpdateSchemaResponse
Updates the schema name with a new name.
-
#update_typed_link_facet(params = {}) ⇒ Struct
Updates a TypedLinkFacet.
-
#upgrade_applied_schema(params = {}) ⇒ Types::UpgradeAppliedSchemaResponse
Upgrades a single directory in-place using the
PublishedSchemaArnwith schema updates found inMinorVersion. -
#upgrade_published_schema(params = {}) ⇒ Types::UpgradePublishedSchemaResponse
Upgrades a published schema under a new minor version revision using the current contents of
DevelopmentSchemaArn.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-clouddirectory/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5430 5431 5432 |
# File 'lib/aws-sdk-clouddirectory/client.rb', line 5430 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5433 5434 5435 |
# File 'lib/aws-sdk-clouddirectory/client.rb', line 5433 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#add_facet_to_object(params = {}) ⇒ Struct
Adds a new Facet to an object. An object can have more than one facet applied on it.
85 |
# File 'sig/client.rbs', line 85
def add_facet_to_object: (
|
#apply_schema(params = {}) ⇒ Types::ApplySchemaResponse
Copies the input published schema, at the specified version, into the Directory with the same name and version as that of the published schema.
106 |
# File 'sig/client.rbs', line 106
def apply_schema: (
|
#attach_object(params = {}) ⇒ Types::AttachObjectResponse
Attaches an existing object to another object. An object can be accessed in two ways:
-
Using the path
-
Using
ObjectIdentifier
117 |
# File 'sig/client.rbs', line 117
def attach_object: (
|
#attach_policy(params = {}) ⇒ Struct
Attaches a policy object to a regular object. An object can have a limited number of attached policies.
133 |
# File 'sig/client.rbs', line 133
def attach_policy: (
|
#attach_to_index(params = {}) ⇒ Types::AttachToIndexResponse
Attaches the specified object to the specified index.
149 |
# File 'sig/client.rbs', line 149
def attach_to_index: (
|
#attach_typed_link(params = {}) ⇒ Types::AttachTypedLinkResponse
Attaches a typed link to a specified source and target object. For more information, see Typed Links.
165 |
# File 'sig/client.rbs', line 165
def attach_typed_link: (
|
#batch_read(params = {}) ⇒ Types::BatchReadResponse
Performs all the read operations in a batch.
188 |
# File 'sig/client.rbs', line 188
def batch_read: (
|
#batch_write(params = {}) ⇒ Types::BatchWriteResponse
Performs all the write operations in a batch. Either all the operations succeed or none.
320 |
# File 'sig/client.rbs', line 320
def batch_write: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5403 5404 5405 5406 5407 5408 5409 5410 5411 5412 5413 5414 5415 5416 5417 5418 5419 |
# File 'lib/aws-sdk-clouddirectory/client.rb', line 5403 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CloudDirectory') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-clouddirectory' context[:gem_version] = '1.93.0' Seahorse::Client::Request.new(handlers, context) end |
#create_directory(params = {}) ⇒ Types::CreateDirectoryResponse
Creates a Directory by copying the published schema into the directory. A directory cannot be created without a schema.
You can also quickly create a directory using a managed schema, called
the QuickStartSchema. For more information, see Managed Schema
in the Amazon Cloud Directory Developer Guide.
474 |
# File 'sig/client.rbs', line 474
def create_directory: (
|
#create_facet(params = {}) ⇒ Struct
Creates a new Facet in a schema. Facet creation is allowed only in development or applied schemas.
484 |
# File 'sig/client.rbs', line 484
def create_facet: (
|
#create_index(params = {}) ⇒ Types::CreateIndexResponse
Creates an index object. See Indexing and search for more information.
500 |
# File 'sig/client.rbs', line 500
def create_index: (
|
#create_object(params = {}) ⇒ Types::CreateObjectResponse
Creates an object in a Directory. Additionally attaches the object to
a parent, if a parent reference and LinkName is specified. An object
is simply a collection of Facet attributes. You can also use this API
call to create a policy object, if the facet from which you create the
object is a policy facet.
522 |
# File 'sig/client.rbs', line 522
def create_object: (
|
#create_schema(params = {}) ⇒ Types::CreateSchemaResponse
Creates a new schema in a development state. A schema can exist in three phases:
-
Development: This is a mutable phase of the schema. All new schemas are in the development phase. Once the schema is finalized, it can be published.
-
Published: Published schemas are immutable and have a version associated with them.
-
Applied: Applied schemas are mutable in a way that allows you to add new schema facets. You can also add new, nonrequired attributes to existing schema facets. You can apply only published schemas to directories.
545 |
# File 'sig/client.rbs', line 545
def create_schema: (
|
#create_typed_link_facet(params = {}) ⇒ Struct
Creates a TypedLinkFacet. For more information, see Typed Links.
554 |
# File 'sig/client.rbs', line 554
def create_typed_link_facet: (
|
#delete_directory(params = {}) ⇒ Types::DeleteDirectoryResponse
Deletes a directory. Only disabled directories can be deleted. A deleted directory cannot be undone. Exercise extreme caution when deleting directories.
571 |
# File 'sig/client.rbs', line 571
def delete_directory: (
|
#delete_facet(params = {}) ⇒ Struct
Deletes a given Facet. All attributes and Rules that are associated with the facet will be deleted. Only development schema facets are allowed deletion.
580 |
# File 'sig/client.rbs', line 580
def delete_facet: (
|
#delete_object(params = {}) ⇒ Struct
Deletes an object and its associated attributes. Only objects with no children and no parents can be deleted. The maximum number of attributes that can be deleted during an object deletion is 30. For more information, see Amazon Cloud Directory Limits.
590 |
# File 'sig/client.rbs', line 590
def delete_object: (
|
#delete_schema(params = {}) ⇒ Types::DeleteSchemaResponse
Deletes a given schema. Schemas in a development and published state can only be deleted.
603 |
# File 'sig/client.rbs', line 603
def delete_schema: (
|
#delete_typed_link_facet(params = {}) ⇒ Struct
Deletes a TypedLinkFacet. For more information, see Typed Links.
612 |
# File 'sig/client.rbs', line 612
def delete_typed_link_facet: (
|
#detach_from_index(params = {}) ⇒ Types::DetachFromIndexResponse
Detaches the specified object from the specified index.
623 |
# File 'sig/client.rbs', line 623
def detach_from_index: (
|
#detach_object(params = {}) ⇒ Types::DetachObjectResponse
Detaches a given object from the parent object. The object that is to be detached from the parent is specified by the link name.
639 |
# File 'sig/client.rbs', line 639
def detach_object: (
|
#detach_policy(params = {}) ⇒ Struct
Detaches a policy from an object.
652 |
# File 'sig/client.rbs', line 652
def detach_policy: (
|
#detach_typed_link(params = {}) ⇒ Struct
Detaches a typed link from a specified source and target object. For more information, see Typed Links.
664 |
# File 'sig/client.rbs', line 664
def detach_typed_link: (
|
#disable_directory(params = {}) ⇒ Types::DisableDirectoryResponse
Disables the specified directory. Disabled directories cannot be read or written to. Only enabled directories can be disabled. Disabled directories may be reenabled.
675 |
# File 'sig/client.rbs', line 675
def disable_directory: (
|
#enable_directory(params = {}) ⇒ Types::EnableDirectoryResponse
Enables the specified directory. Only disabled directories can be enabled. Once enabled, the directory can then be read and written to.
685 |
# File 'sig/client.rbs', line 685
def enable_directory: (
|
#get_applied_schema_version(params = {}) ⇒ Types::GetAppliedSchemaVersionResponse
Returns current applied schema version ARN, including the minor version in use.
695 |
# File 'sig/client.rbs', line 695
def get_applied_schema_version: (
|
#get_directory(params = {}) ⇒ Types::GetDirectoryResponse
Retrieves metadata about a directory.
705 |
# File 'sig/client.rbs', line 705
def get_directory: (
|
#get_facet(params = {}) ⇒ Types::GetFacetResponse
Gets details of the Facet, such as facet name, attributes, Rules, or
ObjectType. You can call this on all kinds of schema facets --
published, development, or applied.
715 |
# File 'sig/client.rbs', line 715
def get_facet: (
|
#get_link_attributes(params = {}) ⇒ Types::GetLinkAttributesResponse
Retrieves attributes that are associated with a typed link.
726 |
# File 'sig/client.rbs', line 726
def get_link_attributes: (
|
#get_object_attributes(params = {}) ⇒ Types::GetObjectAttributesResponse
Retrieves attributes within a facet that are associated with an object.
739 |
# File 'sig/client.rbs', line 739
def get_object_attributes: (
|
#get_object_information(params = {}) ⇒ Types::GetObjectInformationResponse
Retrieves metadata about an object.
759 |
# File 'sig/client.rbs', line 759
def get_object_information: (
|
#get_schema_as_json(params = {}) ⇒ Types::GetSchemaAsJsonResponse
Retrieves a JSON representation of the schema. See JSON Schema Format for more information.
774 |
# File 'sig/client.rbs', line 774
def get_schema_as_json: (
|
#get_typed_link_facet_information(params = {}) ⇒ Types::GetTypedLinkFacetInformationResponse
Returns the identity attribute order for a specific TypedLinkFacet. For more information, see Typed Links.
784 |
# File 'sig/client.rbs', line 784
def get_typed_link_facet_information: (
|
#list_applied_schema_arns(params = {}) ⇒ Types::ListAppliedSchemaArnsResponse
Lists schema major versions applied to a directory. If SchemaArn is
provided, lists the minor version.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
796 |
# File 'sig/client.rbs', line 796
def list_applied_schema_arns: (
|
#list_attached_indices(params = {}) ⇒ Types::ListAttachedIndicesResponse
Lists indices attached to the specified object.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
810 |
# File 'sig/client.rbs', line 810
def list_attached_indices: (
|
#list_development_schema_arns(params = {}) ⇒ Types::ListDevelopmentSchemaArnsResponse
Retrieves each Amazon Resource Name (ARN) of schemas in the development state.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
827 |
# File 'sig/client.rbs', line 827
def list_development_schema_arns: (
|
#list_directories(params = {}) ⇒ Types::ListDirectoriesResponse
Lists directories created within an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
839 |
# File 'sig/client.rbs', line 839
def list_directories: (
|
#list_facet_attributes(params = {}) ⇒ Types::ListFacetAttributesResponse
Retrieves attributes attached to the facet.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
852 |
# File 'sig/client.rbs', line 852
def list_facet_attributes: (
|
#list_facet_names(params = {}) ⇒ Types::ListFacetNamesResponse
Retrieves the names of facets that exist in a schema.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
866 |
# File 'sig/client.rbs', line 866
def list_facet_names: (
|
#list_incoming_typed_links(params = {}) ⇒ Types::ListIncomingTypedLinksResponse
Returns a paginated list of all the incoming TypedLinkSpecifier information for an object. It also supports filtering by typed link facet and identity attributes. For more information, see Typed Links.
879 |
# File 'sig/client.rbs', line 879
def list_incoming_typed_links: (
|
#list_index(params = {}) ⇒ Types::ListIndexResponse
Lists objects attached to the specified index.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
903 |
# File 'sig/client.rbs', line 903
def list_index: (
|
#list_managed_schema_arns(params = {}) ⇒ Types::ListManagedSchemaArnsResponse
Lists the major version families of each managed schema. If a major version ARN is provided as SchemaArn, the minor version revisions in that family are listed instead.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
923 |
# File 'sig/client.rbs', line 923
def list_managed_schema_arns: (
|
#list_object_attributes(params = {}) ⇒ Types::ListObjectAttributesResponse
Lists all attributes that are associated with an object.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
936 |
# File 'sig/client.rbs', line 936
def list_object_attributes: (
|
#list_object_children(params = {}) ⇒ Types::ListObjectChildrenResponse
Returns a paginated list of child objects that are associated with a given object.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
957 |
# File 'sig/client.rbs', line 957
def list_object_children: (
|
#list_object_parent_paths(params = {}) ⇒ Types::ListObjectParentPathsResponse
Retrieves all available parent paths for any object type such as node, leaf node, policy node, and index node objects. For more information about objects, see Directory Structure.
Use this API to evaluate all parents for an object. The call returns
all objects from the root of the directory up to the requested object.
The API returns the number of paths based on user-defined
MaxResults, in case there are multiple paths to the parent. The
order of the paths and nodes returned is consistent among multiple API
calls unless the objects are deleted or moved. Paths not leading to
the directory root are ignored from the target object.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
974 |
# File 'sig/client.rbs', line 974
def list_object_parent_paths: (
|
#list_object_parents(params = {}) ⇒ Types::ListObjectParentsResponse
Lists parent objects that are associated with a given object in pagination fashion.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
991 |
# File 'sig/client.rbs', line 991
def list_object_parents: (
|
#list_object_policies(params = {}) ⇒ Types::ListObjectPoliciesResponse
Returns policies attached to an object in pagination fashion.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1009 |
# File 'sig/client.rbs', line 1009
def list_object_policies: (
|
#list_outgoing_typed_links(params = {}) ⇒ Types::ListOutgoingTypedLinksResponse
Returns a paginated list of all the outgoing TypedLinkSpecifier information for an object. It also supports filtering by typed link facet and identity attributes. For more information, see Typed Links.
1026 |
# File 'sig/client.rbs', line 1026
def list_outgoing_typed_links: (
|
#list_policy_attachments(params = {}) ⇒ Types::ListPolicyAttachmentsResponse
Returns all of the ObjectIdentifiers to which a given policy is
attached.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1050 |
# File 'sig/client.rbs', line 1050
def list_policy_attachments: (
|
#list_published_schema_arns(params = {}) ⇒ Types::ListPublishedSchemaArnsResponse
Lists the major version families of each published schema. If a major
version ARN is provided as SchemaArn, the minor version revisions in
that family are listed instead.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1067 |
# File 'sig/client.rbs', line 1067
def list_published_schema_arns: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns tags for a resource. Tagging is currently supported only for directories with a limit of 50 tags per directory. All 50 tags are returned for a given directory with this API call.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1080 |
# File 'sig/client.rbs', line 1080
def list_tags_for_resource: (
|
#list_typed_link_facet_attributes(params = {}) ⇒ Types::ListTypedLinkFacetAttributesResponse
Returns a paginated list of all attribute definitions for a particular TypedLinkFacet. For more information, see Typed Links.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1093 |
# File 'sig/client.rbs', line 1093
def list_typed_link_facet_attributes: (
|
#list_typed_link_facet_names(params = {}) ⇒ Types::ListTypedLinkFacetNamesResponse
Returns a paginated list of TypedLink facet names for a particular
schema. For more information, see Typed Links.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1107 |
# File 'sig/client.rbs', line 1107
def list_typed_link_facet_names: (
|
#lookup_policy(params = {}) ⇒ Types::LookupPolicyResponse
Lists all policies from the root of the Directory to the object
specified. If there are no policies present, an empty list is
returned. If policies are present, and if some objects don't have the
policies attached, it returns the ObjectIdentifier for such objects.
If policies are present, it returns ObjectIdentifier, policyId,
and policyType. Paths that don't lead to the root from the target
object are ignored. For more information, see Policies.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1120 |
# File 'sig/client.rbs', line 1120
def lookup_policy: (
|
#publish_schema(params = {}) ⇒ Types::PublishSchemaResponse
Publishes a development schema with a major version and a recommended minor version.
1135 |
# File 'sig/client.rbs', line 1135
def publish_schema: (
|
#put_schema_from_json(params = {}) ⇒ Types::PutSchemaFromJsonResponse
Allows a schema to be updated using JSON upload. Only available for development schemas. See JSON Schema Format for more information.
1148 |
# File 'sig/client.rbs', line 1148
def put_schema_from_json: (
|
#remove_facet_from_object(params = {}) ⇒ Struct
Removes the specified facet from the specified object.
1158 |
# File 'sig/client.rbs', line 1158
def remove_facet_from_object: (
|
#tag_resource(params = {}) ⇒ Struct
An API operation for adding tags to a resource.
1174 |
# File 'sig/client.rbs', line 1174
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
An API operation for removing tags from a resource.
1189 |
# File 'sig/client.rbs', line 1189
def untag_resource: (
|
#update_facet(params = {}) ⇒ Struct
Does the following:
-
Adds new
Attributes,Rules, orObjectTypes. -
Updates existing
Attributes,Rules, orObjectTypes. -
Deletes existing
Attributes,Rules, orObjectTypes.
1199 |
# File 'sig/client.rbs', line 1199
def update_facet: (
|
#update_link_attributes(params = {}) ⇒ Struct
Updates a given typed link’s attributes. Attributes to be updated must
not contribute to the typed link’s identity, as defined by its
IdentityAttributeOrder.
1216 |
# File 'sig/client.rbs', line 1216
def update_link_attributes: (
|
#update_object_attributes(params = {}) ⇒ Types::UpdateObjectAttributesResponse
Updates a given object's attributes.
1230 |
# File 'sig/client.rbs', line 1230
def update_object_attributes: (
|
#update_schema(params = {}) ⇒ Types::UpdateSchemaResponse
Updates the schema name with a new name. Only development schema names can be updated.
1246 |
# File 'sig/client.rbs', line 1246
def update_schema: (
|
#update_typed_link_facet(params = {}) ⇒ Struct
Updates a TypedLinkFacet. For more information, see Typed Links.
1256 |
# File 'sig/client.rbs', line 1256
def update_typed_link_facet: (
|
#upgrade_applied_schema(params = {}) ⇒ Types::UpgradeAppliedSchemaResponse
Upgrades a single directory in-place using the PublishedSchemaArn
with schema updates found in MinorVersion. Backwards-compatible
minor version upgrades are instantaneously available for readers on
all objects in the directory. Note: This is a synchronous API call and
upgrades only one schema on a given directory per call. To upgrade
multiple directories from one schema, you would need to call this API
on each directory.
1275 |
# File 'sig/client.rbs', line 1275
def upgrade_applied_schema: (
|
#upgrade_published_schema(params = {}) ⇒ Types::UpgradePublishedSchemaResponse
Upgrades a published schema under a new minor version revision using
the current contents of DevelopmentSchemaArn.
1287 |
# File 'sig/client.rbs', line 1287
def upgrade_published_schema: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5423 5424 5425 |
# File 'lib/aws-sdk-clouddirectory/client.rb', line 5423 def waiter_names [] end |