Class: Aws::CloudDirectory::Types::UpdateLinkAttributesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-clouddirectory/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_updatesArray<Types::LinkAttributeUpdate>

The attributes update structure.



5316
5317
5318
5319
5320
5321
5322
# File 'lib/aws-sdk-clouddirectory/types.rb', line 5316

class UpdateLinkAttributesRequest < Struct.new(
  :directory_arn,
  :typed_link_specifier,
  :attribute_updates)
  SENSITIVE = []
  include Aws::Structure
end

#directory_arnString

The Amazon Resource Name (ARN) that is associated with the Directory where the updated typed link resides. For more information, see arns or Typed Links.



5316
5317
5318
5319
5320
5321
5322
# File 'lib/aws-sdk-clouddirectory/types.rb', line 5316

class UpdateLinkAttributesRequest < Struct.new(
  :directory_arn,
  :typed_link_specifier,
  :attribute_updates)
  SENSITIVE = []
  include Aws::Structure
end

Allows a typed link specifier to be accepted as input.



5316
5317
5318
5319
5320
5321
5322
# File 'lib/aws-sdk-clouddirectory/types.rb', line 5316

class UpdateLinkAttributesRequest < Struct.new(
  :directory_arn,
  :typed_link_specifier,
  :attribute_updates)
  SENSITIVE = []
  include Aws::Structure
end